@@ -23,7 +23,7 @@
 Integration specific to Unix-like operating systems
 """
 
-from __future__ import absolute_import, print_function
+from __future__ import absolute_import
 
 import bleachbit
 from bleachbit import FileUtilities, General
@@ -296,7 +296,6 @@ class Locales:
          'so': 'Soomaaliga',
          'sq': 'Shqip',
          'sr': 'Српски',
-         'sr': 'Српски (ijekavian)',
          'ss': 'SiSwati',
          'st': 'Sesotho',
          'su': 'Basa Sunda',
@@ -508,7 +507,10 @@ def is_running_linux(exename):
         except OSError:
             # 13 = permission denied
             continue
-        if exename == os.path.basename(target):
+        # Google Chrome shows 74 on Ubuntu 19.04 shows up as
+        # /opt/google/chrome/chrome (deleted)
+        found_exename = os.path.basename(target).replace(' (deleted)', '')
+        if exename == found_exename:
             return True
     return False
 
@@ -549,37 +551,6 @@ def rotated_logs():
             yield path
 
 
-def start_with_computer(enabled):
-    """If enabled, create shortcut to start application with computer.
-    If disabled, then delete the shortcut."""
-    if not enabled:
-        # User requests to not automatically start BleachBit
-        if os.path.lexists(bleachbit.autostart_path):
-            # Delete the shortcut
-            FileUtilities.delete(bleachbit.autostart_path)
-        return
-    # User requests to automatically start BleachBit
-    if os.path.lexists(bleachbit.autostart_path):
-        # Already automatic, so exit
-        return
-    if not os.path.exists(bleachbit.launcher_path):
-        logger.error('%s does not exist: ', bleachbit.launcher_path)
-        return
-    autostart_dir = os.path.dirname(bleachbit.autostart_path)
-    if not os.path.exists(autostart_dir):
-        General.makedirs(autostart_dir)
-    import shutil
-    shutil.copy(bleachbit.launcher_path, bleachbit.autostart_path)
-    os.chmod(bleachbit.autostart_path, 0o755)
-    if General.sudo_mode():
-        General.chownself(bleachbit.autostart_path)
-
-
-def start_with_computer_check():
-    """Return boolean whether BleachBit will start with the computer"""
-    return os.path.lexists(bleachbit.autostart_path)
-
-
 def wine_to_linux_path(wineprefix, windows_pathname):
     """Return a Linux pathname from an absolute Windows pathname and Wine prefix"""
     drive_letter = windows_pathname[0]
@@ -618,7 +589,11 @@ def run_cleaner_cmd(cmd, args, freed_space_regex=r'[\d.]+[kMGTE]?B?', error_line
 def journald_clean():
     """Clean the system journals"""
     freed_space_regex = '^Vacuuming done, freed ([\d.]+[KMGT]?) of archived journals on disk.$'
-    return run_cleaner_cmd('journalctl', ['--vacuum-size=1'], freed_space_regex)
+    try:
+        return run_cleaner_cmd('journalctl', ['--vacuum-size=1'], freed_space_regex)
+    except subprocess.CalledProcessError as e:
+        raise RuntimeError("Error calling '%s':\n%s" % (' '.join(e.cmd), e.output))
+
 
 
 def apt_autoremove():
