@@ -37,7 +37,7 @@ These are the terms:
 
 """
 
-from __future__ import absolute_import, print_function
+from __future__ import absolute_import
 
 import bleachbit
 from bleachbit import Command, FileUtilities, General
@@ -114,9 +114,9 @@ def browse_files(_, title):
     return pathnames
 
 
-def browse_folder(hwnd, title):
+def browse_folder(_, title):
     """Ask the user to select a folder.  Return full path."""
-    pidl = shell.SHBrowseForFolder(hwnd, None, title)[0]
+    pidl = shell.SHBrowseForFolder(None, None, title)[0]
     if pidl is None:
         # user cancelled
         return None
@@ -170,7 +170,6 @@ def delete_registry_value(key, value_name, really_delete):
         raise
     else:
         return True
-    raise RuntimeError('Unknown error in delete_registry_value')
 
 
 def delete_registry_key(parent_key, really_delete):
@@ -276,9 +275,7 @@ def elevate_privileges():
         exe = sys.executable.decode(sys.getfilesystemencoding())
         parameters = "--gui --no-uac"
     else:
-        # __file__ is absolute path to bleachbit/Windows.py
-        pydir = os.path.dirname(__file__.decode(sys.getfilesystemencoding()))
-        pyfile = os.path.join(pydir, 'GUI.py')
+        pyfile = os.path.join(bleachbit.bleachbit_exe_path, 'bleachbit.py')
         # If the Python file is on a network drive, do not offer the UAC because
         # the administrator may not have privileges and user will not be
         # prompted.
@@ -330,30 +327,6 @@ def empty_recycle_bin(path, really_delete):
         shell.SHEmptyRecycleBin(None, path, flags)
     return bytes_used
 
-
-def get_autostart_path():
-    """Return the path of the BleachBit shortcut in the user's startup folder"""
-    try:
-        startupdir = shell.SHGetSpecialFolderPath(None, shellcon.CSIDL_STARTUP)
-    except:
-        # example of failure
-        # https://www.bleachbit.org/forum/error-windows-7-x64-bleachbit-091
-        logger.exception('exception in get_autostart_path()')
-        msg = 'Error finding user startup folder: %s ' % (
-            str(sys.exc_info()[1]))
-        from bleachbit import GuiBasic
-        GuiBasic.message_dialog(None, msg)
-        # as a fallback, guess
-        # Windows XP: C:\Documents and Settings\(username)\Start Menu\Programs\Startup
-        # Windows 7:
-        # C:\Users\(username)\AppData\Roaming\Microsoft\Windows\Start
-        # Menu\Programs\Startup
-        startupdir = bleachbit.expandvars('$USERPROFILE\\Start Menu\\Programs\\Startup')
-        if not os.path.exists(startupdir):
-            startupdir = bleachbit.expandvars('$APPDATA\\Roaming\\Microsoft\\Windows\\Start Menu\\Programs\\Startup')
-    return os.path.join(startupdir, 'bleachbit.lnk')
-
-
 def get_clipboard_paths():
     """Return a tuple of Unicode pathnames from the clipboard"""
     import win32clipboard
@@ -597,7 +570,7 @@ def set_environ(varname, path):
     try:
         if not os.path.exists(path):
             raise RuntimeError('Variable %s points to a non-existent path %s' % (varname, path))
-        os.environ[varname] = path.encode('utf8')
+        os.environ[varname] = path if isinstance(path, str) else path.encode('utf8')
     except:
         logger.exception('set_environ(%s, %s): exception when setting environment variable', varname, path)
 
@@ -640,29 +613,3 @@ def split_registry_key(full_key):
         raise RuntimeError("Invalid Windows registry hive '%s'" % k1)
     return hive_map[k1], k2
 
-
-def start_with_computer(enabled):
-    """If enabled, create shortcut to start application with computer.
-    If disabled, then delete the shortcut."""
-    autostart_path = get_autostart_path()
-    if not enabled:
-        if os.path.lexists(autostart_path):
-            FileUtilities.delete(autostart_path)
-        return
-    if os.path.lexists(autostart_path):
-        return
-    import winshell
-    winshell.CreateShortcut(Path=autostart_path,
-                            Target=os.path.join(bleachbit.bleachbit_exe_path, 'bleachbit.exe'))
-
-    # import win32com.client
-    # wscript_shell = win32com.client.Dispatch('WScript.Shell')
-    # shortcut = wscript_shell.CreateShortCut(autostart_path)
-    # shortcut.TargetPath = os.path.join(
-    #     Common.bleachbit_exe_path, 'bleachbit.exe')
-    # shortcut.save()
-
-
-def start_with_computer_check():
-    """Return boolean whether BleachBit will start with the computer"""
-    return os.path.lexists(get_autostart_path())
